==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/BlobNfsTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties pertaining to the BlobNfsTarget.
 * @property target Resource ID of the storage container.
 * @property usageModel Identifies the StorageCache usage model to be used for this storage target.
 * @property verificationTimer Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
 * @property writeBackTimer Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
 */
public data class BlobNfsTargetArgs(
    public val target: Output<String>? = null,
    public val usageModel: Output<String>? = null,
    public val verificationTimer: Output<Int>? = null,
    public val writeBackTimer: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs> {
    override fun toJava(): com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs =
        com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs.builder()
            .target(target?.applyValue({ args0 -> args0 }))
            .usageModel(usageModel?.applyValue({ args0 -> args0 }))
            .verificationTimer(verificationTimer?.applyValue({ args0 -> args0 }))
            .writeBackTimer(writeBackTimer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobNfsTargetArgs].
 */
@PulumiTagMarker
public class BlobNfsTargetArgsBuilder internal constructor() {
    private var target: Output<String>? = null

    private var usageModel: Output<String>? = null

    private var verificationTimer: Output<Int>? = null

    private var writeBackTimer: Output<Int>? = null

    /**
     * @param value Resource ID of the storage container.
     */
    @JvmName("mpdkcnwlemnfqfme")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Identifies the StorageCache usage model to be used for this storage target.
     */
    @JvmName("fpwcwqqkbyoqnvob")
    public suspend fun usageModel(`value`: Output<String>) {
        this.usageModel = value
    }

    /**
     * @param value Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
     */
    @JvmName("rnktsutauypohsir")
    public suspend fun verificationTimer(`value`: Output<Int>) {
        this.verificationTimer = value
    }

    /**
     * @param value Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
     */
    @JvmName("nxepghnygannixdp")
    public suspend fun writeBackTimer(`value`: Output<Int>) {
        this.writeBackTimer = value
    }

    /**
     * @param value Resource ID of the storage container.
     */
    @JvmName("wfcukhhawdasunvj")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param value Identifies the StorageCache usage model to be used for this storage target.
     */
    @JvmName("vtgrtpitwnbrnyyy")
    public suspend fun usageModel(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usageModel = mapped
    }

    /**
     * @param value Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
     */
    @JvmName("bkhvmaqdapwgxdnh")
    public suspend fun verificationTimer(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.verificationTimer = mapped
    }

    /**
     * @param value Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
     */
    @JvmName("bicxftwbecmrxhon")
    public suspend fun writeBackTimer(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.writeBackTimer = mapped
    }

    internal fun build(): BlobNfsTargetArgs = BlobNfsTargetArgs(
        target = target,
        usageModel = usageModel,
        verificationTimer = verificationTimer,
        writeBackTimer = writeBackTimer,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/BlobNfsTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties pertaining to the BlobNfsTarget.
 * @property target Resource ID of the storage container.
 * @property usageModel Identifies the StorageCache usage model to be used for this storage target.
 * @property verificationTimer Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
 * @property writeBackTimer Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
 */
public data class BlobNfsTargetArgs(
    public val target: Output<String>? = null,
    public val usageModel: Output<String>? = null,
    public val verificationTimer: Output<Int>? = null,
    public val writeBackTimer: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs> {
    override fun toJava(): com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs =
        com.pulumi.azurenative.storagecache.inputs.BlobNfsTargetArgs.builder()
            .target(target?.applyValue({ args0 -> args0 }))
            .usageModel(usageModel?.applyValue({ args0 -> args0 }))
            .verificationTimer(verificationTimer?.applyValue({ args0 -> args0 }))
            .writeBackTimer(writeBackTimer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BlobNfsTargetArgs].
 */
@PulumiTagMarker
public class BlobNfsTargetArgsBuilder internal constructor() {
    private var target: Output<String>? = null

    private var usageModel: Output<String>? = null

    private var verificationTimer: Output<Int>? = null

    private var writeBackTimer: Output<Int>? = null

    /**
     * @param value Resource ID of the storage container.
     */
    @JvmName("qavyeavpqmyfhlmn")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Identifies the StorageCache usage model to be used for this storage target.
     */
    @JvmName("basubgbnekkvxwiy")
    public suspend fun usageModel(`value`: Output<String>) {
        this.usageModel = value
    }

    /**
     * @param value Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
     */
    @JvmName("icraphuwurytvten")
    public suspend fun verificationTimer(`value`: Output<Int>) {
        this.verificationTimer = value
    }

    /**
     * @param value Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
     */
    @JvmName("gedtokklbepqmrsb")
    public suspend fun writeBackTimer(`value`: Output<Int>) {
        this.writeBackTimer = value
    }

    /**
     * @param value Resource ID of the storage container.
     */
    @JvmName("hbbvfwdcepjfxmft")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    /**
     * @param value Identifies the StorageCache usage model to be used for this storage target.
     */
    @JvmName("cbjgvahyaxpwwfkn")
    public suspend fun usageModel(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usageModel = mapped
    }

    /**
     * @param value Amount of time (in seconds) the cache waits before it checks the back-end storage for file updates.
     */
    @JvmName("usssktjvrtwyianw")
    public suspend fun verificationTimer(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.verificationTimer = mapped
    }

    /**
     * @param value Amount of time (in seconds) the cache waits after the last file change before it copies the changed file to back-end storage.
     */
    @JvmName("elrmokwxbqetygth")
    public suspend fun writeBackTimer(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.writeBackTimer = mapped
    }

    internal fun build(): BlobNfsTargetArgs = BlobNfsTargetArgs(
        target = target,
        usageModel = usageModel,
        verificationTimer = verificationTimer,
        writeBackTimer = writeBackTimer,
    )
}
